<?php
/** 
 * ץ륯饹
 *
 * 2. åλ 
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: index.php,v 1.3 2007/01/28 07:12:49 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class Example2_Index
{
    var $parameter1;
    var $parameter2;
    var $parameter3;

    /**
     * 󥹥ȥ饯
     *
     * @access public
     */
    function Example2_Index()
    {
        // νҤǤޤ
        // /examples.php/example2/ ˥ϡ᥽åɤƤʤΤǡ
        // νǽλ$template_dir/example2/index.html ƥץ졼Ȥɤ߽Фޤ
    }

    /**
     * ѥ᡼session1ξΥ᥽å
     *
     * @access public
     * @param object ꥯȥ֥
     * @param object ǡ֥
     */
    function executeSession1(&$request, &$dm)
    {
        // åѥ᡼򥻥å
        $request->setSession('parameter1', 'åڡ1Ǥ');
        // ӥ塼Ϥѥ᡼򥻥å
        $this->parameter1 = $request->getSession('parameter1');

        // $template_dir/example2/session1.html ƥץ졼Ȥ
        $dm->setTemplateFile('example2/session1.html');
    }
  
    /**
     * ѥ᡼session2ξΥ᥽å
     *
     * @access public
     * @param object ꥯȥ֥
     * @param object ǡ֥
     */
    function executeSession2(&$request, &$dm)
    {
        // åѥ᡼򥻥å
        $request->setSession('parameter2', 'åڡ2Ǥ');
        // ӥ塼Ϥѥ᡼򥻥å
        $this->parameter1 = $request->getSession('parameter1');
        $this->parameter2 = $request->getSession('parameter2');

        // $template_dir/example2/session2.html ƥץ졼Ȥ
        $dm->setTemplateFile('example2/session2.html');
    }

    /**
     * ѥ᡼session3ξΥ᥽å
     *
     * @access public
     * @param object ꥯȥ֥
     * @param object ǡ֥
     */
    function executeSession3(&$request, &$dm)
    {
        // åѥ᡼򥻥å
        $request->setSession('parameter3', 'åڡ3Ǥ');
        // ӥ塼Ϥѥ᡼򥻥å
        $this->parameter1 = $request->getSession('parameter1');
        $this->parameter2 = $request->getSession('parameter2');
        $this->parameter3 = $request->getSession('parameter3');

        // $template_dir/example2/session3.html ƥץ졼Ȥ
        $dm->setTemplateFile('example2/session3.html');
    }

    /**
     * ѥ᡼session4ξΥ᥽å
     *
     * @access public
     * @param object ꥯȥ֥
     * @param object ǡ֥
     */
    function executeSession4(&$request, &$dm)
    {
        // åѥ᡼
        $session =& $request->getSessionObject();
        $session->deleteParameters();

        // ӥ塼Ϥѥ᡼򥻥åȡʺ줿ǧ
        $this->parameter1 = $session->getParameter('parameter1');
        $this->parameter2 = $session->getParameter('parameter2');
        $this->parameter3 = $session->getParameter('parameter3');

        // $template_dir/example2/session4.html ƥץ졼Ȥ
        $dm->setTemplateFile('example2/session4.html');
    }
}

?>
